%%
%This script takes PROMISE data and plots it to compare temperatures in
%summer 2014 and summer 2015
%Written and run in MATLAB 2014b

%%
%Data Download
%Go to http://promice.org/DataDownload.html
%Register and request KAN_B, KAN_L, and KAN_U daily data
%For this study, data (accessed 14 Jan 2016) were available through 
%2 Sept 2015, resulting in slight truncation of the summer 2015 data.

%%
%Data ingest into MATLAB
%Edit file locations in lines 8, 59, and 110
filename = '_______________________/KAN_B_day.txt';
delimiter = ' ';
formatSpec = '%s%s%s%s%s%s%s%[^\n\r]';
fileID = fopen(filename,'r');
dataArray = textscan(fileID, formatSpec, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true,  'ReturnOnError', false);
fclose(fileID);
raw = repmat({''},length(dataArray{1}),length(dataArray)-1);
for col=1:length(dataArray)-1
    raw(1:length(dataArray{col}),col) = dataArray{col};
end
numericData = NaN(size(dataArray{1},1),size(dataArray,2));
for col=[1,2,3,4,5,6,7]
    % Converts strings in the input cell array to numbers. Replaced non-numeric
    % strings with NaN.
    rawData = dataArray{col};
    for row=1:size(rawData, 1);
        % Create a regular expression to detect and remove non-numeric prefixes and
        % suffixes.
        regexstr = '(?<prefix>.*?)(?<numbers>([-]*(\d+[\,]*)+[\.]{0,1}\d*[eEdD]{0,1}[-+]*\d*[i]{0,1})|([-]*(\d+[\,]*)*[\.]{1,1}\d+[eEdD]{0,1}[-+]*\d*[i]{0,1}))(?<suffix>.*)';
        try
            result = regexp(rawData{row}, regexstr, 'names');
            numbers = result.numbers;
            
            % Detected commas in non-thousand locations.
            invalidThousandsSeparator = false;
            if any(numbers==',');
                thousandsRegExp = '^\d+?(\,\d{3})*\.{0,1}\d*$';
                if isempty(regexp(thousandsRegExp, ',', 'once'));
                    numbers = NaN;
                    invalidThousandsSeparator = true;
                end
            end
            % Convert numeric strings to numbers.
            if ~invalidThousandsSeparator;
                numbers = textscan(strrep(numbers, ',', ''), '%f');
                numericData(row, col) = numbers{1};
                raw{row, col} = numbers{1};
            end
        catch me
        end
    end
end
R = cellfun(@(x) ~isnumeric(x) && ~islogical(x),raw); % Find non-numeric cells
raw(R) = {NaN}; % Replace non-numeric cells
KB_Year = cell2mat(raw(:, 1));
KB_MonthOfYear = cell2mat(raw(:, 2));
KB_DayOfMonth = cell2mat(raw(:, 3));
KB_DayOfYear = cell2mat(raw(:, 4));
KB_AirTemperatureC = cell2mat(raw(:, 7));
clearvars filename delimiter formatSpec fileID dataArray ans raw col numericData rawData row regexstr result numbers invalidThousandsSeparator thousandsRegExp me R;

filename = '_______________________/KAN_L_day.txt';
delimiter = ' ';
formatSpec = '%s%s%s%s%s%s%s%[^\n\r]';
fileID = fopen(filename,'r');
dataArray = textscan(fileID, formatSpec, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true,  'ReturnOnError', false);
fclose(fileID);
raw = repmat({''},length(dataArray{1}),length(dataArray)-1);
for col=1:length(dataArray)-1
    raw(1:length(dataArray{col}),col) = dataArray{col};
end
numericData = NaN(size(dataArray{1},1),size(dataArray,2));
for col=[1,2,3,4,5,6,7]
    % Converts strings in the input cell array to numbers. Replaced non-numeric
    % strings with NaN.
    rawData = dataArray{col};
    for row=1:size(rawData, 1);
        % Create a regular expression to detect and remove non-numeric prefixes and
        % suffixes.
        regexstr = '(?<prefix>.*?)(?<numbers>([-]*(\d+[\,]*)+[\.]{0,1}\d*[eEdD]{0,1}[-+]*\d*[i]{0,1})|([-]*(\d+[\,]*)*[\.]{1,1}\d+[eEdD]{0,1}[-+]*\d*[i]{0,1}))(?<suffix>.*)';
        try
            result = regexp(rawData{row}, regexstr, 'names');
            numbers = result.numbers;
            
            % Detected commas in non-thousand locations.
            invalidThousandsSeparator = false;
            if any(numbers==',');
                thousandsRegExp = '^\d+?(\,\d{3})*\.{0,1}\d*$';
                if isempty(regexp(thousandsRegExp, ',', 'once'));
                    numbers = NaN;
                    invalidThousandsSeparator = true;
                end
            end
            % Convert numeric strings to numbers.
            if ~invalidThousandsSeparator;
                numbers = textscan(strrep(numbers, ',', ''), '%f');
                numericData(row, col) = numbers{1};
                raw{row, col} = numbers{1};
            end
        catch me
        end
    end
end
R = cellfun(@(x) ~isnumeric(x) && ~islogical(x),raw); % Find non-numeric cells
raw(R) = {NaN}; % Replace non-numeric cells
KB_Year = cell2mat(raw(:, 1));
KB_MonthOfYear = cell2mat(raw(:, 2));
KB_DayOfMonth = cell2mat(raw(:, 3));
KB_DayOfYear = cell2mat(raw(:, 4));
KB_AirTemperatureC = cell2mat(raw(:, 7));
clearvars filename delimiter formatSpec fileID dataArray ans raw col numericData rawData row regexstr result numbers invalidThousandsSeparator thousandsRegExp me R;

filename = '_______________________/KAN_U_day.txt';
delimiter = ' ';
formatSpec = '%s%s%s%s%s%s%s%[^\n\r]';
fileID = fopen(filename,'r');
dataArray = textscan(fileID, formatSpec, 'Delimiter', delimiter, 'MultipleDelimsAsOne', true,  'ReturnOnError', false);
fclose(fileID);
raw = repmat({''},length(dataArray{1}),length(dataArray)-1);
for col=1:length(dataArray)-1
    raw(1:length(dataArray{col}),col) = dataArray{col};
end
numericData = NaN(size(dataArray{1},1),size(dataArray,2));
for col=[1,2,3,4,5,6,7]
    % Converts strings in the input cell array to numbers. Replaced non-numeric
    % strings with NaN.
    rawData = dataArray{col};
    for row=1:size(rawData, 1);
        % Create a regular expression to detect and remove non-numeric prefixes and
        % suffixes.
        regexstr = '(?<prefix>.*?)(?<numbers>([-]*(\d+[\,]*)+[\.]{0,1}\d*[eEdD]{0,1}[-+]*\d*[i]{0,1})|([-]*(\d+[\,]*)*[\.]{1,1}\d+[eEdD]{0,1}[-+]*\d*[i]{0,1}))(?<suffix>.*)';
        try
            result = regexp(rawData{row}, regexstr, 'names');
            numbers = result.numbers;
            
            % Detected commas in non-thousand locations.
            invalidThousandsSeparator = false;
            if any(numbers==',');
                thousandsRegExp = '^\d+?(\,\d{3})*\.{0,1}\d*$';
                if isempty(regexp(thousandsRegExp, ',', 'once'));
                    numbers = NaN;
                    invalidThousandsSeparator = true;
                end
            end
            % Convert numeric strings to numbers.
            if ~invalidThousandsSeparator;
                numbers = textscan(strrep(numbers, ',', ''), '%f');
                numericData(row, col) = numbers{1};
                raw{row, col} = numbers{1};
            end
        catch me
        end
    end
end
R = cellfun(@(x) ~isnumeric(x) && ~islogical(x),raw); % Find non-numeric cells
raw(R) = {NaN}; % Replace non-numeric cells
KB_Year = cell2mat(raw(:, 1));
KB_MonthOfYear = cell2mat(raw(:, 2));
KB_DayOfMonth = cell2mat(raw(:, 3));
KB_DayOfYear = cell2mat(raw(:, 4));
KB_AirTemperatureC = cell2mat(raw(:, 7));
clearvars filename delimiter formatSpec fileID dataArray ans raw col numericData rawData row regexstr result numbers invalidThousandsSeparator thousandsRegExp me R;

%%
%Consolidate daily variables
KAN_B = struct('Year',KB_Year,...
                'MonthOfYear',KB_MonthOfYear,...
                'DayOfMonth',KB_DayOfMonth,...
                'DayofYear',KB_DayOfYear,...
                'AirTemperatureC',KB_AirTemperatureC);
KAN_L = struct('Year',KL_Year,...
                'MonthOfYear',KL_MonthOfYear,...
                'DayOfMonth',KL_DayOfMonth,...
                'DayofYear',KL_DayOfYear,...
                'AirTemperatureC',KL_AirTemperatureC);
KAN_U = struct('Year',KU_Year,...
                'MonthOfYear',KU_MonthOfYear,...
                'DayOfMonth',KU_DayOfMonth,...
                'DayofYear',KU_DayOfYear,...
                'AirTemperatureC',KU_AirTemperatureC);
%Clean up
clear KB* KL* KU*  
save KAN_promice_data

%%
%For 2014 and 2015, calculate a running average...
temp = KAN_B;
year = 2014;
    index = find(temp.Year == year);
    running = zeros(size(index));
    decimalDay = zeros(size(index));
    for day = 1:size(index,1)
        running(day) = nanmean(temp.AirTemperatureC((index(day)-3):(index(day)+3)));
        decimalDay(day) = temp.Year(index(day)) + temp.DayofYear(index(day))/366;
    end
KAN_B_weekly_smoothed_2014 = [decimalDay, running];
clear temp index day running decimalDay year

temp = KAN_B;
year = 2015;
    index = find(temp.Year == year);
    running = zeros(size(index));
    decimalDay = zeros(size(index));
    for day = 1:size(index,1)-3
        running(day) = nanmean(temp.AirTemperatureC((index(day)-3):(index(day)+3)));
        decimalDay(day) = temp.Year(index(day)) + temp.DayofYear(index(day))/366;
    end
KAN_B_weekly_smoothed_2015 = [decimalDay, running];
KAN_B_weekly_smoothed_2015 = KAN_B_weekly_smoothed_2015(1:242,:);
clear temp index day running decimalDay year

temp = KAN_U;
year = 2014;
    index = find(temp.Year == year);
    running = zeros(size(index));
    decimalDay = zeros(size(index));
    for day = 1:size(index,1)
        running(day) = nanmean(temp.AirTemperatureC((index(day)-3):(index(day)+3)));
        decimalDay(day) = temp.Year(index(day)) + temp.DayofYear(index(day))/366;
    end
KAN_U_weekly_smoothed_2014 = [decimalDay, running];
clear temp index day running decimalDay year

temp = KAN_U;
year = 2015;
    index = find(temp.Year == year);
    running = zeros(size(index));
    decimalDay = zeros(size(index));
    for day = 1:size(index,1)-3
        running(day) = nanmean(temp.AirTemperatureC((index(day)-3):(index(day)+3)));
        decimalDay(day) = temp.Year(index(day)) + temp.DayofYear(index(day))/366;
    end
KAN_U_weekly_smoothed_2015 = [decimalDay, running];
KAN_U_weekly_smoothed_2015 = KAN_U_weekly_smoothed_2015(1:242,:);
clear temp index day running decimalDay year

temp = KAN_L;
year = 2014;
    index = find(temp.Year == year);
    running = zeros(size(index));
    decimalDay = zeros(size(index));
    for day = 1:size(index,1)
        running(day) = nanmean(temp.AirTemperatureC((index(day)-3):(index(day)+3)));
        decimalDay(day) = temp.Year(index(day)) + temp.DayofYear(index(day))/366;
    end
KAN_L_weekly_smoothed_2014 = [decimalDay, running];
clear temp index day running decimalDay year

temp = KAN_L;
year = 2015;
    index = find(temp.Year == year);
    running = zeros(size(index));
    decimalDay = zeros(size(index));
    for day = 1:size(index,1)-3
        running(day) = nanmean(temp.AirTemperatureC((index(day)-3):(index(day)+3)));
        decimalDay(day) = temp.Year(index(day)) + temp.DayofYear(index(day))/366;
    end
KAN_L_weekly_smoothed_2015 = [decimalDay, running];
KAN_L_weekly_smoothed_2015 = KAN_L_weekly_smoothed_2015(1:242,:);
clear temp index day running decimalDay year

clear KAN_B KAN_L KAN_U
save KAN_promice_weekly_smoothed_2014_2015

%%
%Plotting the results
figure();
plot(KAN_B_weekly_smoothed_2014(:,1)-2014,KAN_B_weekly_smoothed_2014(:,2));
hold on
plot(KAN_B_weekly_smoothed_2015(:,1)-2015,KAN_B_weekly_smoothed_2015(:,2));
axis([152/365,243/365,-30,15]); %show 1 june through 31 august
legend('KAN B 2014','KAN B 2015');
hold off

figure();
plot(KAN_U_weekly_smoothed_2014(:,1)-2014,KAN_U_weekly_smoothed_2014(:,2));
hold on
plot(KAN_U_weekly_smoothed_2015(:,1)-2015,KAN_U_weekly_smoothed_2015(:,2));
axis([152/365,243/365,-30,15]); %show 1 june through 31 august
legend('KAN U 2014','KAN U 2015');
hold off

figure();
plot(KAN_L_weekly_smoothed_2014(:,1)-2014,KAN_L_weekly_smoothed_2014(:,2));
hold on
plot(KAN_L_weekly_smoothed_2015(:,1)-2015,KAN_L_weekly_smoothed_2015(:,2));
axis([152/365,243/365,-30,15]); %show 1 june through 31 august
legend('KAN L 2014','KAN L 2015');
hold off

%%
%Figure was then produced in Adobe Illustrator




